==> openshift-model-monitoring-5.11.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/StorageSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.model.EphemeralVolumeSource;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.EmptyDirVolumeSource;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StorageSpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<A>{
  public StorageSpecFluentImpl() {
  }
  public StorageSpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance) {
    this.withDisableMountSubPath(instance.getDisableMountSubPath()); 
    this.withEmptyDir(instance.getEmptyDir()); 
    this.withEphemeral(instance.getEphemeral()); 
    this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean disableMountSubPath;
  private io.fabric8.kubernetes.api.model.EmptyDirVolumeSource emptyDir;
  private io.fabric8.kubernetes.api.model.EphemeralVolumeSource ephemeral;
  private io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder volumeClaimTemplate;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getDisableMountSubPath() {
    return this.disableMountSubPath;
  }
  public A withDisableMountSubPath(java.lang.Boolean disableMountSubPath) {
    this.disableMountSubPath=disableMountSubPath; return (A) this;
  }
  public java.lang.Boolean hasDisableMountSubPath() {
    return this.disableMountSubPath != null;
  }
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSource getEmptyDir() {
    return this.emptyDir;
  }
  public A withEmptyDir(io.fabric8.kubernetes.api.model.EmptyDirVolumeSource emptyDir) {
    this.emptyDir=emptyDir; return (A) this;
  }
  public java.lang.Boolean hasEmptyDir() {
    return this.emptyDir != null;
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSource getEphemeral() {
    return this.ephemeral;
  }
  public A withEphemeral(io.fabric8.kubernetes.api.model.EphemeralVolumeSource ephemeral) {
    this.ephemeral=ephemeral; return (A) this;
  }
  public java.lang.Boolean hasEphemeral() {
    return this.ephemeral != null;
  }
  
  /**
   * This method has been deprecated, please use method buildVolumeClaimTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim getVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim buildVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public A withVolumeClaimTemplate(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim volumeClaimTemplate) {
    _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate);
    if (volumeClaimTemplate!=null){ this.volumeClaimTemplate= new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder(volumeClaimTemplate); _visitables.get("volumeClaimTemplate").add(this.volumeClaimTemplate);} return (A) this;
  }
  public java.lang.Boolean hasVolumeClaimTemplate() {
    return this.volumeClaimTemplate != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplate() {
    return new io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluentImpl.VolumeClaimTemplateNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplateLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluentImpl.VolumeClaimTemplateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> editVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplateLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim item) {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageSpecFluentImpl that = (StorageSpecFluentImpl) o;
    if (disableMountSubPath != null ? !disableMountSubPath.equals(that.disableMountSubPath) :that.disableMountSubPath != null) return false;
    if (emptyDir != null ? !emptyDir.equals(that.emptyDir) :that.emptyDir != null) return false;
    if (ephemeral != null ? !ephemeral.equals(that.ephemeral) :that.ephemeral != null) return false;
    if (volumeClaimTemplate != null ? !volumeClaimTemplate.equals(that.volumeClaimTemplate) :that.volumeClaimTemplate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disableMountSubPath,  emptyDir,  ephemeral,  volumeClaimTemplate,  additionalProperties,  super.hashCode());
  }
  public class VolumeClaimTemplateNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    VolumeClaimTemplateNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder(this, item);
    }
    VolumeClaimTemplateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder builder;
    public N and() {
      return (N) StorageSpecFluentImpl.this.withVolumeClaimTemplate(builder.build());
    }
    public N endVolumeClaimTemplate() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/StorageSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.model.EphemeralVolumeSource;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.EmptyDirVolumeSource;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StorageSpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<A>{
  public StorageSpecFluentImpl() {
  }
  public StorageSpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance) {
    this.withDisableMountSubPath(instance.getDisableMountSubPath()); 
    this.withEmptyDir(instance.getEmptyDir()); 
    this.withEphemeral(instance.getEphemeral()); 
    this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean disableMountSubPath;
  private io.fabric8.kubernetes.api.model.EmptyDirVolumeSource emptyDir;
  private io.fabric8.kubernetes.api.model.EphemeralVolumeSource ephemeral;
  private io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder volumeClaimTemplate;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getDisableMountSubPath() {
    return this.disableMountSubPath;
  }
  public A withDisableMountSubPath(java.lang.Boolean disableMountSubPath) {
    this.disableMountSubPath=disableMountSubPath; return (A) this;
  }
  public java.lang.Boolean hasDisableMountSubPath() {
    return this.disableMountSubPath != null;
  }
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSource getEmptyDir() {
    return this.emptyDir;
  }
  public A withEmptyDir(io.fabric8.kubernetes.api.model.EmptyDirVolumeSource emptyDir) {
    this.emptyDir=emptyDir; return (A) this;
  }
  public java.lang.Boolean hasEmptyDir() {
    return this.emptyDir != null;
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSource getEphemeral() {
    return this.ephemeral;
  }
  public A withEphemeral(io.fabric8.kubernetes.api.model.EphemeralVolumeSource ephemeral) {
    this.ephemeral=ephemeral; return (A) this;
  }
  public java.lang.Boolean hasEphemeral() {
    return this.ephemeral != null;
  }
  
  /**
   * This method has been deprecated, please use method buildVolumeClaimTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim getVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim buildVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public A withVolumeClaimTemplate(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim volumeClaimTemplate) {
    _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate);
    if (volumeClaimTemplate!=null){ this.volumeClaimTemplate= new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder(volumeClaimTemplate); _visitables.get("volumeClaimTemplate").add(this.volumeClaimTemplate);} return (A) this;
  }
  public java.lang.Boolean hasVolumeClaimTemplate() {
    return this.volumeClaimTemplate != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplate() {
    return new io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluentImpl.VolumeClaimTemplateNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplateLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluentImpl.VolumeClaimTemplateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> editVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplateLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim item) {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageSpecFluentImpl that = (StorageSpecFluentImpl) o;
    if (disableMountSubPath != null ? !disableMountSubPath.equals(that.disableMountSubPath) :that.disableMountSubPath != null) return false;
    if (emptyDir != null ? !emptyDir.equals(that.emptyDir) :that.emptyDir != null) return false;
    if (ephemeral != null ? !ephemeral.equals(that.ephemeral) :that.ephemeral != null) return false;
    if (volumeClaimTemplate != null ? !volumeClaimTemplate.equals(that.volumeClaimTemplate) :that.volumeClaimTemplate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disableMountSubPath,  emptyDir,  ephemeral,  volumeClaimTemplate,  additionalProperties,  super.hashCode());
  }
  public class VolumeClaimTemplateNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent.VolumeClaimTemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    VolumeClaimTemplateNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder(this, item);
    }
    VolumeClaimTemplateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimBuilder builder;
    public N and() {
      return (N) StorageSpecFluentImpl.this.withVolumeClaimTemplate(builder.build());
    }
    public N endVolumeClaimTemplate() {
      return and();
    }
    
  }
  
}
